@@ -12,7 +12,9 @@ from qrunner.utils.log import logger
 from qrunner.utils.decorate import *
 from qrunner.utils.mock import mock, mock_en, RandomData, CommonData
 from qrunner.utils.config import conf
+from qrunner.core.image.element import ImageElement
+from qrunner.core.pc.driver import PcDriver
 
-__version__ = "0.9.37"
+__version__ = "0.9.46"
 __description__ = "全栈自动化测试框架"
 
