@@ -459,8 +459,9 @@ class TestCase(HttpRequest):
         """
         断言状态码
         """
-        assert ResponseResult.status_code == status_code, \
-            f'status_code {ResponseResult} != {status_code}'
+        with step(f'断言响应状态码 == {status_code}'):
+            assert ResponseResult.status_code == status_code, \
+                f'status_code {ResponseResult} != {status_code}'
 
     @staticmethod
     def assertPath(path, value):
@@ -468,8 +469,9 @@ class TestCase(HttpRequest):
         断言响应json中对应path的值等于value
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert search_value == value, f'{search_value} != {value}'
+        with step(f'断言响应中 {path} == {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert search_value == value, f'{search_value} != {value}'
 
     @staticmethod
     def assertEq(path, value):
@@ -477,8 +479,9 @@ class TestCase(HttpRequest):
         assertPath换个名字
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert search_value == value, f'{search_value} != {value}'
+        with step(f'断言响应中 {path} == {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert search_value == value, f'{search_value} != {value}'
 
     @staticmethod
     def assertLenEq(path, value):
@@ -486,8 +489,9 @@ class TestCase(HttpRequest):
         断言列表长度等于多少
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
+        with step(f'断言响应中 {path} 的长度 == {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
 
     @staticmethod
     def assertLenGt(path, value):
@@ -495,8 +499,9 @@ class TestCase(HttpRequest):
         断言列表长度大于多少
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
+        with step(f'断言响应中 {path} 的长度 > {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
     def assertLenGtOrEq(path, value):
@@ -504,8 +509,9 @@ class TestCase(HttpRequest):
         断言列表长度大于等于多少
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert len(search_value) >= value, f"{search_value} 的长度不大于 {value}"
+        with step(f'断言响应中 {path} 的长度 >= {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert len(search_value) >= value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
     def assertLenLt(path, value):
@@ -513,8 +519,9 @@ class TestCase(HttpRequest):
         断言列表长度小于多少
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert len(search_value) < value, f"{search_value} 的长度不大于 {value}"
+        with step(f'断言响应中 {path} 的长度 < {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert len(search_value) < value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
     def assertLenLtOrEq(path, value):
@@ -522,8 +529,9 @@ class TestCase(HttpRequest):
         断言列表长度小于等于多少
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert len(search_value) <= value, f"{search_value} 的长度不大于 {value}"
+        with step(f'断言响应中 {path} 的长度 <= {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert len(search_value) <= value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
     def assertGt(path, value):
@@ -531,8 +539,9 @@ class TestCase(HttpRequest):
         值大于多少
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert int(search_value) > int(value), f"{search_value} 不大于 {value}"
+        with step(f'断言响应中 {path} > {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert int(search_value) > int(value), f"{search_value} 不大于 {value}"
 
     @staticmethod
     def assertGtOrEq(path, value):
@@ -540,10 +549,11 @@ class TestCase(HttpRequest):
         值大于等于
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        if isinstance(search_value, str):
-            search_value = int(search_value)
-        assert search_value >= value, f"{search_value} 小于 {value}"
+        with step(f'断言响应中 {path} >= {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            if isinstance(search_value, str):
+                search_value = int(search_value)
+            assert search_value >= value, f"{search_value} 小于 {value}"
 
     @staticmethod
     def assertLt(path, value):
@@ -551,8 +561,9 @@ class TestCase(HttpRequest):
         值小于多少
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert int(search_value) < int(value), f"{search_value} 不大于 {value}"
+        with step(f'断言响应中 {path} < {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert int(search_value) < int(value), f"{search_value} 不大于 {value}"
 
     @staticmethod
     def assertLtOrEq(path, value):
@@ -560,8 +571,9 @@ class TestCase(HttpRequest):
         值小于等于多少
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert int(search_value) <= int(value), f"{search_value} 不大于 {value}"
+        with step(f'断言响应中 {path} <= {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert int(search_value) <= int(value), f"{search_value} 不大于 {value}"
 
     @staticmethod
     def assertNotEq(path, value):
@@ -569,23 +581,36 @@ class TestCase(HttpRequest):
         值不等于
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert search_value != value, f"{search_value} 等于 {value}"
+        with step(f'断言响应中 {path} != {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert search_value != value, f"{search_value} 等于 {value}"
 
     @staticmethod
-    def assertIn(path, value_list: list):
+    def assertIn(path, value):
         """
         断言匹配结果被value_list包含
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert search_value in value_list, f"{value_list} 不包含 {search_value}"
+        with step(f'断言响应中 {path} 被 {value} 包含'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert search_value in value, f"{value} 不包含 {search_value}"
+
+    @staticmethod
+    def assertNotIn(path, value):
+        """
+        断言匹配结果不被value_list包含
+        doc: https://jmespath.org/
+        """
+        with step(f'断言响应中 {path} 不被 {value} 包含'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert search_value not in value, f"{value} 包含 {search_value}"
 
     @staticmethod
     def assertNotExists(path):
         """断言字段不存在"""
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert search_value is None, f'仍然包含 {path} 为 {search_value}'
+        with step(f'断言响应中 {path} 值为None或字段不存在'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert search_value is None, f'仍然包含 {path} 为 {search_value}'
 
     @staticmethod
     def assertContains(path, value):
@@ -593,8 +618,19 @@ class TestCase(HttpRequest):
         断言匹配结果包含value
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert value in search_value, f"{search_value} 不包含 {value}"
+        with step(f'断言响应中 {path} 包含 {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert value in search_value, f"{search_value} 不包含 {value}"
+
+    @staticmethod
+    def assertNotContains(path, value):
+        """
+        断言匹配结果不包含value
+        doc: https://jmespath.org/
+        """
+        with step(f'断言响应中 {path} 不包含 {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert value not in search_value, f"{search_value} 包含 {value}"
 
     @staticmethod
     def assertTypeMatch(path, value_type):
@@ -602,20 +638,21 @@ class TestCase(HttpRequest):
         类型匹配
         doc: https://jmespath.org/
         """
-        if not isinstance(value_type, type):
-            if value_type == 'int':
-                value_type = int
-            elif value_type == 'str':
-                value_type = str
-            elif value_type == 'list':
-                value_type = list
-            elif value_type == 'dict':
-                value_type = dict
-            else:
-                value_type = str
+        with step(f'断言响应中 {path} 的数据类型等于 {value_type}'):
+            if not isinstance(value_type, type):
+                if value_type == 'int':
+                    value_type = int
+                elif value_type == 'str':
+                    value_type = str
+                elif value_type == 'list':
+                    value_type = list
+                elif value_type == 'dict':
+                    value_type = dict
+                else:
+                    value_type = str
 
-        search_value = jmespath.search(path, ResponseResult.response)
-        assert isinstance(search_value, value_type), f'{search_value} 不是 {value_type} 类型'
+            search_value = jmespath.search(path, ResponseResult.response)
+            assert isinstance(search_value, value_type), f'{search_value} 不是 {value_type} 类型'
 
     @staticmethod
     def assertStartsWith(path, value):
@@ -623,8 +660,9 @@ class TestCase(HttpRequest):
         以什么开头
         doc: https://jmespath.org/
         """
-        search_value: str = jmespath.search(path, ResponseResult.response)
-        assert search_value.startswith(value), f'{search_value} 不以 {value} 开头'
+        with step(f'断言响应中 {path} 以 {value} 开头'):
+            search_value: str = jmespath.search(path, ResponseResult.response)
+            assert search_value.startswith(value), f'{search_value} 不以 {value} 开头'
 
     @staticmethod
     def assertEndsWith(path, value):
@@ -632,8 +670,9 @@ class TestCase(HttpRequest):
         以什么结尾
         doc: https://jmespath.org/
         """
-        search_value: str = jmespath.search(path, ResponseResult.response)
-        assert search_value.endswith(value), f'{search_value} 不以 {value} 结尾'
+        with step(f'断言响应中 {path} 以 {value} 结尾'):
+            search_value: str = jmespath.search(path, ResponseResult.response)
+            assert search_value.endswith(value), f'{search_value} 不以 {value} 结尾'
 
     @staticmethod
     def assertRegexMatch(path, value):
@@ -641,9 +680,10 @@ class TestCase(HttpRequest):
         正则匹配
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        match_obj = re.match(r'' + value, search_value, flags=re.I)
-        assert match_obj is not None, f'结果 {search_value} 匹配失败'
+        with step(f'断言响应中 {path} 正则匹配表达式 {value}'):
+            search_value = jmespath.search(path, ResponseResult.response)
+            match_obj = re.match(r'' + value, search_value, flags=re.I)
+            assert match_obj is not None, f'结果 {search_value} 匹配失败'
 
 
 class Page:
@@ -683,53 +723,45 @@ class Page:
         else:
             self.driver.screenshot(desc, rect=element.rect)
 
-    def click(self, **kwargs):
+    def click(self, element):
         """点击"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[点击 {desc}]'
+        step_desc = f'[点击 {element.desc}]'
         with step(step_desc):
             try:
-                element = self.element(**kwargs)
                 element.click()
             except Exception as e:
                 raise AssertionError(str(e))
             else:
                 self.screenshot(step_desc, element)
 
-    def click_exists(self, **kwargs):
+    def click_exists(self, element):
         """存在才点击"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[存在才点击 {desc}]'
+        step_desc = f'[存在才点击 {element.desc}]'
         with step(step_desc):
             try:
-                element = self.element(**kwargs)
                 element.click_exists()
             except Exception as e:
                 raise AssertionError(str(e))
             else:
                 self.screenshot(step_desc, element)
 
-    def set_text(self, text, **kwargs):
+    def set_text(self, element, text):
         """输入"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[点击 {desc} 后输入 {text}]'
+        step_desc = f'[点击 {element.desc} 后输入 {text}]'
         with step(step_desc):
             try:
-                element = self.element(**kwargs)
                 element.set_text(text)
             except Exception as e:
                 raise AssertionError(str(e))
             else:
                 self.screenshot(step_desc, element)
 
-    def set_password(self, text, **kwargs):
+    def set_password(self, element, text):
         """输入密码，仅安卓使用"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[点击 {desc} 后输入 {text}]'
+        step_desc = f'[点击 {element.desc} 后输入 {text}]'
         with step(step_desc):
             try:
                 if isinstance(self.driver, AndroidDriver):
-                    element = self.element(**kwargs)
                     element.click()
                     self.driver.set_password(text)
                 else:
@@ -740,26 +772,23 @@ class Page:
             else:
                 self.screenshot(step_desc, element)
 
-    def clear_text(self, **kwargs):
+    def clear_text(self, element):
         """清除输入框"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[点击 {desc} 后清除文本]'
+        step_desc = f'[点击 {element.desc} 后清除文本]'
         with step(step_desc):
             try:
-                element = self.element(**kwargs)
                 element.clear_text()
             except Exception as e:
                 raise AssertionError(str(e))
             else:
                 self.screenshot(step_desc, element)
 
-    def get_text(self, **kwargs):
+    @staticmethod
+    def get_text(element):
         """获取文本属性"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[获取 {desc} 的文本]'
+        step_desc = f'[获取 {element.desc} 的文本]'
         with step(step_desc):
             try:
-                element = self.element(**kwargs)
                 return element.text
             except Exception as e:
                 raise AssertionError(str(e))
@@ -808,40 +837,37 @@ class Page:
             finally:
                 self.driver.screenshot(step_desc)
 
-    def assertElement(self, timeout=5, **kwargs):
+    def assertElement(self, element, timeout=5):
         """断言元素存在"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[断言控件 {desc} 存在]'
+        step_desc = f'[断言控件 {element.desc} 存在]'
         with step(step_desc):
             try:
                 for _ in range(timeout + 1):
                     try:
-                        element = self.element(**kwargs)
-                        assert element.exists(), f'元素 {kwargs} 不存在'
+                        assert element.exists(), f'元素 {element.desc} 不存在'
                         break
                     except AssertionError:
                         time.sleep(1)
                 else:
-                    assert self.element(**kwargs).exists(), f'元素 {kwargs} 不存在'
+                    assert element.exists(), f'元素 {element.desc} 不存在'
             except Exception as e:
                 raise AssertionError(str(e))
             else:
                 self.screenshot(step_desc, element)
 
-    def assertNotElement(self, timeout=5, **kwargs):
+    def assertNotElement(self, element, timeout=5):
         """断言元素不存在"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[断言控件 {desc} 不存在]'
+        step_desc = f'[断言控件 {element.desc} 不存在]'
         with step(step_desc):
             try:
                 for _ in range(timeout + 1):
                     try:
-                        assert not self.element(**kwargs).exists(), f'元素 {kwargs} 仍然存在'
+                        assert not element.exists(), f'元素 {element.desc} 仍然存在'
                         break
                     except AssertionError:
                         time.sleep(1)
                 else:
-                    assert not self.element(**kwargs).exists(), f'元素 {kwargs} 仍然存在'
+                    assert not element.exists(), f'元素 {element.desc} 仍然存在'
             except Exception as e:
                 raise AssertionError(str(e))
             finally:
@@ -859,13 +885,11 @@ class Page:
             finally:
                 self.driver.screenshot(step_desc)
 
-    def click_by_js(self, **kwargs):
+    def click_by_js(self, element):
         """通过js的方式点击"""
-        desc = kwargs.get('desc', '')
-        step_desc = f'[点击 {desc}]'
+        step_desc = f'[点击 {element.desc}]'
         with step(step_desc):
             try:
-                element = self.element(**kwargs)
                 self.driver.click(element)
             except Exception as e:
                 raise AssertionError(str(e))
