@@ -27,12 +27,12 @@ def main():
         elif sys.argv[1] in ["-h", "--help"]:
             # qrun -h
             parser.print_help()
-        elif sys.argv[1] == "create":
+        elif sys.argv[1] == "start":
             # qrun startpro
             sub_parser_project.print_help()
         sys.exit(0)
     else:
-        if sys.argv[1] == "create":
+        if sys.argv[1] == "start":
             args = parser.parse_args()
             main_scaffold_project(args)
         sys.exit(0)
