@@ -238,8 +238,7 @@ class AndroidDriver(object):
         if os.path.exists(img_dir) is False:
             os.mkdir(img_dir)
         time_str = time.strftime('%Y年%m月%d日 %H时%M分%S秒')
-        file_path = os.path.join(img_dir,
-                                 f'{time_str}-{file_name}.png')
+        file_path = os.path.join(img_dir, f'{time_str}-{file_name}.png')
         logger.info(f'截图保存至: {file_path}')
         self.d.screenshot(file_path)
 
@@ -254,6 +253,7 @@ class AndroidDriver(object):
         allure.attach.file(file_path,
                            attachment_type=allure.attachment_type.PNG,
                            name=f'{time_str}-{file_name}.png')
+        return file_path
 
     # def upload_pic(self, filename):
     #     self.screenshot('tmp.png')
