@@ -2,6 +2,7 @@ import inspect
 import json
 import os
 import time
+import typing
 from multiprocessing.dummy import Pool as ThreadPool
 from typing import Union
 from uiautomator2 import UiObject
@@ -165,11 +166,20 @@ class AndroidElement(object):
             return False
         return True
 
-    def click(self):
+    def _adapt_center(self, e: typing.Union[UiObject, XPathSelector], offset=(0.5, 0.5)):
+        if isinstance(e, UiObject):
+            return e.center(offset=offset)
+        else:
+            return e.offset(offset[0], offset[1])
+
+    def click(self, offset=(0.5, 0.5)):
         logger.info(f'点击元素: {self._kwargs},{self._index}')
         element = self.get_element()
         print('点击元素')
-        element.click()
+        # 这种方式经常点击不成功，感觉是页面刷新有影响
+        # element.click()
+        x, y = self._adapt_center(element, offset=offset)
+        self._d.click(x, y)
         print('点击成功')
 
     def click_exists(self):
