@@ -3,6 +3,8 @@
 # @File    : request.py
 import sys
 from urllib import parse
+
+import allure
 import requests
 import json as json_util
 from qrunner.utils.config import conf
@@ -17,17 +19,19 @@ def request(func):
         print("\n")
         logger.info('-------------- Request -----------------[🚀]')
         try:
-            url = list(args)[1]
+            path = list(args)[1]
         except IndexError:
-            url = kwargs.get("url", "")
+            path = kwargs.get("url", "")
 
-        if "http" not in url:
+        if "http" not in path:
             base_url = conf.get_item('common', 'base_url')
             if 'http' in base_url:
-                url = parse.urljoin(base_url, url)
+                url = parse.urljoin(base_url, path)
             else:
                 logger.debug('请设置正确的base_url')
                 sys.exit()
+        else:
+            url = path
 
         img_file = False
         file_type = url.split(".")[-1]
@@ -64,11 +68,17 @@ def request(func):
         params = kwargs.get("params", "")
         data = kwargs.get("data", "")
         json = kwargs.get("json", "")
+        desc = kwargs.pop("desc", None)
+
+        # running function
+        if desc is None:
+            desc = f'请求 {path} 接口'
+        with allure.step(desc):
+            r = func(*args, **kwargs)
+
         if auth != "":
             logger.debug(f"[auth]:\n {json_util.dumps(auth)} \n")
-        if headers != "":
-            # logger.debug(type(headers))
-            logger.debug(f"[headers]:\n {json_util.dumps(headers)} \n")
+        logger.debug(f"[headers]:\n {r.request.headers} \n")
         if cookies != "":
             logger.debug(f"[cookies]:\n {json_util.dumps(cookies)} \n")
         if params != "":
@@ -78,9 +88,6 @@ def request(func):
         if json != "":
             logger.debug(f"[json]:\n json: {json_util.dumps(json)} \n python: {json}")
 
-        # running function
-        r = func(*args, **kwargs)
-
         ResponseResult.status_code = r.status_code
         logger.info("-------------- Response ----------------")
         try:
@@ -89,13 +96,14 @@ def request(func):
             logger.debug(f"[response]:\n {resp} \n")
             ResponseResult.response = resp
         except BaseException as msg:
-            logger.debug("[warning]: {} \n".format(msg))
+            # 非json响应数据，最多打印100个字符
+            logger.debug("[warning]: {} \n".format(str(msg)[:100]))
             if img_file is True:
                 logger.debug("[type]: {}".format(file_type))
                 ResponseResult.response = r.content
             else:
                 logger.debug("[type]: text \n")
-                logger.debug(f"[response]:\n {r.text} \n")
+                logger.debug(f"[response]:\n {r.text[:100]} \n")
                 ResponseResult.response = r.text
 
     return wrapper
