@@ -1,8 +1,9 @@
-import json
 import os
+import subprocess
 import sys
 import time
 import allure
+import requests
 from baseImage import Image, Rect
 from selenium import webdriver
 from qrunner.utils.config import conf
@@ -25,6 +26,55 @@ from qrunner.core.android.driver import AndroidDriver
 #             self.d = H5Driver(conf.get_name('app', 'serial_no'))
 #     return wrapper
 
+def get_server_chrome_versions():
+    """获取淘宝镜像网站上所有的版本列表"""
+    version_list = []
+    url = "https://registry.npmmirror.com/-/binary/chromedriver/"
+    rep = requests.get(url).json()
+    for item in rep:
+        version_list.append(item["name"])
+    return version_list
+
+
+def get_webview_version(serial_no, pkg_name):
+    """通过shell命令获取webview对应chrome的版本号"""
+    # 获取应用的pid
+    pid = subprocess.getoutput(f'adb -s {serial_no} shell ps | grep {pkg_name}').split(' ')[6]
+    print(pid)
+
+    # 获取webview的socket名称
+    socket_name = subprocess.getoutput(f'adb -s {serial_no} shell cat /proc/net/unix | grep --binary-file=text webview').split(' ')[-1][1:]
+    print(socket_name)
+
+    # 将webview端口转发到本地
+    cmd = f'adb -s {serial_no} forward tcp:5000 localabstract:{socket_name}'
+    print(cmd)
+    subprocess.getoutput(cmd)
+
+    # 请求本地服务，获取版本号
+    version_data = requests.get('http://127.0.0.1:5000/json/version').json()
+    print(version_data)
+    version = version_data['Browser'].split('/')[1]
+    print(version)
+
+    return version
+
+
+def get_driver_version(serial_no, pkg_name):
+    """获取应用对应的淘宝镜像的chromedriver的版本号"""
+    webview_version = get_webview_version(serial_no, pkg_name)
+
+    version_list = get_server_chrome_versions()
+    if webview_version in version_list:
+        return webview_version
+    else:
+        for version in version_list:
+            if version[0:10] == webview_version[0:10]:
+                return version.split('/')[0]
+        else:
+            print('淘宝镜像未找到匹配本机的chromedriver版本')
+            sys.exit()
+
 
 class H5Driver(object):
     # _instance = {}
@@ -54,22 +104,22 @@ class H5Driver(object):
         options.add_experimental_option('androidPackage', pkg_name)
         options.add_experimental_option('androidUseRunningApp', True)
         options.add_experimental_option('androidProcess', pkg_name)
-        version_list = conf.get_item('app', 'webview_version')
-        for version in version_list:
+        for i in range(3):
             try:
+                version = get_driver_version(serial_no, pkg_name)
                 path_ = ChromeDriverManager(version=version).install()
                 self.d = webdriver.Chrome(
                     executable_path=path_,
                     options=options
                 )
                 logger.debug('h5Driver初始化成功')
-                logger.debug(f'版本 {version} 配对成功')
                 break
-            except:
-                logger.debug(f'版本 {version} 配对失败')
-                continue
+            except Exception as e:
+                logger.debug(f'发生异常: {str(e)}')
+                logger.debug(f'第 {i+1} 次重试')
+                time.sleep(3)
         else:
-            logger.debug(f'配置的版本号都不对: {version_list}')
+            logger.debug('重试3次失败，h5Driver初始化失败')
             sys.exit()
 
         # 设置页面加载超时时间
@@ -126,6 +176,7 @@ class H5Driver(object):
         allure.attach.file(file_path,
                            attachment_type=allure.attachment_type.PNG,
                            name=f'{time_str}-{file_name}.png')
+        return file_path
 
     # @relaunch
     # def upload_pic(self, filename):
