@@ -1,11 +1,11 @@
 import inspect
+import threading
 from typing import Union
 from wda import Selector
 from qrunner.utils.log import logger
 from qrunner.utils.config import conf
-from qrunner.utils.decorate import step
 from qrunner.core.ios.driver import IosDriver
-from multiprocessing.dummy import Pool as ThreadPool
+from multiprocessing import Pool
 from selenium.common.exceptions import NoSuchElementException
 
 
@@ -37,18 +37,13 @@ class IosElement(object):
                 element = self._d.xpath(loc)
             else:
                 element = self._d(label=loc)
-            element.click_exists(timeout=1)
+            element.click_exists()
 
         # 多线程执行点击过程
-        alert_str = conf.get_name('app', 'ios_alert')
-        logger.debug(f'处理异常弹窗: {alert_str}')
-        try:
-            alert_list = alert_str.split(',')
-        except:
-            alert_list = []
-        if alert_list:
-            pool = ThreadPool(10)
-            pool.map(click_alert, alert_list)
+        alert_list = conf.get_item('app', 'ios_alert')
+        print(f'异常弹窗列表: {alert_list}')
+        for alert in alert_list:
+            click_alert(alert)
 
     def _find_element(self, retry=3, timeout=3):
         """
@@ -83,6 +78,8 @@ class IosElement(object):
         if element is None:
             self._driver.screenshot(f'[控件 {self.desc}] 定位失败')
             raise NoSuchElementException(f'[控件 {self.desc}] 定位失败')
+        else:
+            logger.debug('定位成功')
         return element
 
     @property
@@ -135,6 +132,11 @@ class IosElement(object):
         logger.info(f'获取元素: {self._kwargs} 的bounds属性')
         return self.get_element().bounds
 
+    @property
+    def rect(self):
+        logger.info(f'获取元素: {self._kwargs} 的左上角坐标和宽高')
+        return [item * self._d.scale for item in list(self.get_element().bounds)]
+
     def exists(self, timeout=1):
         """
         判断元素是否存在当前页面
@@ -144,7 +146,7 @@ class IosElement(object):
         logger.info(f'元素 {self._kwargs},{self._index} 是否存在:')
         element = self._find_element(retry=0, timeout=timeout)
         if element is None:
-            self._driver.screenshot(f'元素定位失败')
+            # self._driver.screenshot(f'元素定位失败')
             return False
         return True
 
