@@ -52,7 +52,7 @@ class Mail:
         conn.quit()
 
     def send_report(self, title, report_url, receiver_list):
-        report_path = conf.get('common', 'report_path')
+        report_path = conf.get_item('common', 'report_path')
         allure_data = AllureData(report_path).get_basic_info()
         total = allure_data.get('total')
         fail = allure_data.get('fail')
